/**
 * The main executive script.
 *
 * This is the first JavaScript script to be executed.
 */
// @formatter:off
/**
 * Author: $Author: herbert $
 * URL: $HeadURL: svn+ssh://192.168.1.54/var/svn/LCX/Resources/app.js $
 * Revision: $Id: app.js 125 2013-03-07 13:41:57Z herbert $
 */
// @formatter:on

// Declare a flag to indicate whether it is an Android device
var isAndroid = Ti.Platform.osname == 'android';

// Create the main window to be shown
var win = Titanium.UI.createWindow({
    fullscreen : true,
    layout : 'vertical',
    exitOnClose : true,
    navBarHidden : true,
    orientationModes : [Titanium.UI.PORTRAIT],
    backgroundImage : 'images/back_mainpage.png'
});

// Create the main view, which is the region under the LCX title
var MainView = require('ui/common/MainView');
var mainView = new MainView();

// Create the title view, which is shown at the top of the screen, and
// it needs the reference to the main view for updating its language
var TitleView = require('ui/common/TitleView');
var titleView = new TitleView(mainView);

// Add the two views to the main window
win.add(titleView);
win.add(mainView);

/*
 * Check whether the user has specified the language to be used before. If no,
 * show an option dialog to get the language, stores the setting to the device
 * and show the main window after the user has specified the language to be used.
 * Otherwise, just show the window and the language to be used is the setting set
 * by the user before.
 */
var style;
if (Ti.Platform.name === 'iPhone OS') {
    style = Ti.UI.iPhone.ActivityIndicatorStyle.BIG;
} else {
    style = Ti.UI.ActivityIndicatorStyle.BIG;
}
var activityIndicator = Ti.UI.createActivityIndicator({
    style : style,
    height : Ti.UI.SIZE,
    width : Ti.UI.SIZE
});
mainView.add(activityIndicator);

/*
 * When the window is open, load the view contents from URL and show the
 * activity indicator. When all the contents are loaded, hide the indicator.
 */
win.addEventListener('open', function(e) {
    activityIndicator.show();
    mainView.loadContent(function() {
        activityIndicator.hide();
    });
});

var language = Ti.App.Properties.getString("language");
if (language != "chinese" && language != "english") {
    var optionsDialogOpts = {
        options : ['English', '中文'],
        title : 'Language / 語言'
    };

    if (isAndroid) {
        optionsDialogOpts.selectedIndex = 1;
    }

    var dialog = Titanium.UI.createOptionDialog(optionsDialogOpts);

    dialog.addEventListener('click', function(e) {
        Ti.App.Properties.setString("language", e.index == 0 ? "english" : "chinese");
        mainView.updateLanguage();
        win.open();
    });
    dialog.show();
} else {
    win.open();
}

