/**
 * This defines the DirectoryView class. It defines the Directory view of the
 * app. The specified object is the reference to the floor plan map window.
 *
 * For the front page index table, the user can select a category and the page
 * will switch to the second page with the shop list for that category.
 * Afterwards, selecting a shop will switch the app to the third page for shop
 * details. If the user enter some text in the search bar on the first page,
 * the text is used to filter all the shop names. Then, if the user select a
 * shop, it will switch to the third page for the shop details.
 */
// @formatter:off
/**
 * Author: $Author: herbert $
 * URL: $HeadURL: svn+ssh://192.168.1.54/var/svn/LCX/Resources/ui/common/DirectoryView.js $
 * Revision: $Id: DirectoryView.js 125 2013-03-07 13:41:57Z herbert $
 */
// @formatter:on
function DirectoryView(mapWin) {
    /*
     * Variable declarations.
     */
    var mapWindow = mapWin;

    var LANGUAGE_EN = 1;
    var LANGUAGE_TC = 2;

    var language = Ti.App.Properties.getString('language') == "english" ? LANGUAGE_EN : LANGUAGE_TC;

    var platformWidth = Titanium.Platform.displayCaps.platformWidth < Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var platformHeight = Titanium.Platform.displayCaps.platformWidth > Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var widthRatio = platformWidth / 640.0;
    var heightRatio = platformHeight / 960.0;
    var smallRatio = widthRatio < heightRatio ? widthRatio : heightRatio;
    var bigRatio = widthRatio > heightRatio ? widthRatio : heightRatio;
    var fontSize = platformHeight / 40;

    var categories = [];
    var shops = [];

    var categoryTableData;
    var shopTableData = [];
    var allShopData;

    var currentCategory;
    var currentShop;

    // The page to go if the end user click the Back button on the detail page
    var returnPage = 0;

    /*
     * Create this object.
     */
    var self = Titanium.UI.createView({
        top : 15 * smallRatio,
        left : 15 * smallRatio,
        right : 15 * smallRatio,
        bottom : 0 * smallRatio,
        visible : false,
        backgroundImage : '/images/back_popup.png'
    });

    /*
    * Create the GUI.
    */
    // Create the top most scrollable view
    var directoryPane = Ti.UI.createScrollableView({
        scrollingEnabled : false
    });
    self.add(directoryPane);

    // Create the front page
    var dirFrontPage = Ti.UI.createView({
        layout : 'vertical'
    });
    directoryPane.addView(dirFrontPage);

    var shopImage = Ti.UI.createImageView({
        top : 20 * smallRatio,
        bottom : 20 * smallRatio,
        width : platformWidth * 3 / 4,
        height : 'auto',
        image : '/images/store_tst.png'
    });
    var frontSearch = Ti.UI.createSearchBar({
        hintText : (language == LANGUAGE_EN) ? 'Search' : '搜尋',
        showCancel : false
    });

    // The table for showing the different categories
    var frontIndex = Ti.UI.createTableView({
        top : 20 * smallRatio,
        left : 20 * smallRatio,
        right : 20 * smallRatio,
        bottom : 20 * smallRatio,
        search : frontSearch,
        searchHidden : true
    });

    dirFrontPage.add(shopImage);
    dirFrontPage.add(frontIndex);

    // Create the index page
    var dirIndexPage = Ti.UI.createView({
    });
    directoryPane.addView(dirIndexPage);

    var indexSearch = Ti.UI.createSearchBar({
        hintText : (language == LANGUAGE_EN) ? 'Search' : '搜尋',
        showCancel : false
    });
    var indexTable = Ti.UI.createTableView({
        top : 20 * smallRatio,
        left : 20 * smallRatio,
        right : 20 * smallRatio,
        bottom : 50 * smallRatio,
        search : indexSearch,
        searchHidden : true
    });
    var indexButtonPanel = Ti.UI.createView({
        left : 20 * smallRatio,
        right : 20 * smallRatio,
        bottom : 0,
        height : 50 * smallRatio
    });
    dirIndexPage.add(indexTable);
    dirIndexPage.add(indexButtonPanel);

    var indexBack = Ti.UI.createImageView({
        top : 0,
        right : 10 * widthRatio,
        image : (language == LANGUAGE_EN ? '/images/btn_back.png' : '/images/btn_back_tc.png'),
        className : 'indexBack'
    });
    indexButtonPanel.add(indexBack);

    // Create the detail page
    var dirDetailPage = Ti.UI.createView({
        width : 'auto',
        height : 'auto',
    });
    directoryPane.addView(dirDetailPage);

    var dirDetailContent = Ti.UI.createView({
        width : Ti.UI.FILL,
        height : Ti.UI.FILL,
        layout : 'vertical'
    });
    dirDetailPage.add(dirDetailContent);

    var detailPhoto = Ti.UI.createImageView({
        top : 20 * smallRatio,
        width : platformWidth - 80 * widthRatio,
        height : 'auto'
    });
    var shopName = Ti.UI.createLabel({
        top : 20 * smallRatio,
        left : 20 * smallRatio,
        rigth : 20 * smallRatio,
        height : 50 * smallRatio,
        color : 'white',
        font : {
            fontSize : fontSize
        }
    });
    var telPanel = Ti.UI.createView({
        top : 20 * smallRatio,
        width : platformWidth - 50 * widthRatio,
        height : 50 * smallRatio
    });
    var webSite = Ti.UI.createLabel({
        top : 20 * smallRatio,
        width : platformWidth - 50 * widthRatio,
        height : 80 * smallRatio,
        color : 'white',
        font : {
            fontSize : fontSize
        }
    });

    dirDetailContent.add(detailPhoto);
    dirDetailContent.add(shopName);
    dirDetailContent.add(telPanel);
    dirDetailContent.add(webSite);

    var tel = Ti.UI.createLabel({
        top : 10 * smallRatio,
        left : 0,
        color : 'white',
        font : {
            fontSize : fontSize
        }
    });
    var imgFacebook = Ti.UI.createImageView({
        top : 10 * smallRatio,
        left : platformWidth / 2,
        width : 116 * smallRatio,
        height : 40 * smallRatio,
        image : (language == LANGUAGE_EN ? '/images/btn_facebook.png' : '/images/btn_facebook_tc.png')
    });
    var imgEmail = Ti.UI.createImageView({
        top : 10 * smallRatio,
        left : platformWidth - 90 * widthRatio,
        width : 36 * smallRatio,
        height : 35 * smallRatio,
        image : '/images/btn_email.png'
    });
    telPanel.add(tel);
    telPanel.add(imgFacebook);
    telPanel.add(imgEmail);

    var detailButtonPanel = Ti.UI.createView({
        width : Ti.UI.FILL,
        height : 50 * smallRatio,
        bottom : 0
    });
    dirDetailPage.add(detailButtonPanel);

    var detailBack = Ti.UI.createImageView({
        top : 2 * smallRatio,
        right : 10 * widthRatio,
        width : 120 * smallRatio,
        height : 45 * smallRatio,
        image : (language == LANGUAGE_EN ? '/images/btn_back.png' : '/images/btn_back_tc.png')
    });
    detailButtonPanel.add(detailBack);

    /*
     * Utility methods
     */
    function setTableData() {
        frontIndex.setData(categoryTableData);
    }

    /*
     * Public methods
     */
    self.updateDirectory = function(objs) {
        // Partition the specified shop objects according to their categories
        for (var i = 0; i < objs.shop.length; i++) {
            var category = objs.shop[i].category2;
            var shopList = [];
            var j = 0;
            for (; j < categories.length; j++) {
                if (categories[j] == category) {
                    shopList = shops[j];
                    break;
                }
            }
            categories[j] = category;
            shops[j] = shopList;
            shops[j].push(objs.shop[i]);
        }

        // Sort the categories
        for (var i = 0; i < categories.length - 1; i++) {
            for (var j = 0; j < categories.length - i - 1; j++) {
                if (categories[j] > categories[j + 1]) {
                    var temp = categories[j];
                    categories[j] = categories[j + 1];
                    categories[j + 1] = temp;

                    temp = shops[j];
                    shops[j] = shops[j + 1];
                    shops[j + 1] = temp;
                }
            }
        }

        // Sort each category shop list
        for (var k = 0; k < categories.length; k++) {
            var array = shops[k];
            for (var i = 0; i < array.length - 1; i++) {
                for (var j = 0; j < array.length - i - 1; j++) {
                    if (array[j].shop_display.toUpperCase() > array[j + 1].shop_display.toUpperCase()) {
                        var temp = array[j];
                        array[j] = array[j + 1];
                        array[j + 1] = temp;
                    }
                }
            }
        }

        // Prepare the table record lists for each category
        allShopData = [];
        for (var i = 0; i < shops.length; i++) {
            shopTableData[i] = [];
            var indexChar = '';
            for (var j = 0; j < shops[i].length; j++) {
                // Create the table row for its own category
                var thisChar = shops[i][j].shop_display.charAt(0).toUpperCase();
                var row = Ti.UI.createTableViewRow({
                    title : shops[i][j].shop_display,
                    className : 'shopRow',
                    shop : shops[i][j],
                    font : {
                        fontSize : fontSize
                    }
                });
                if (indexChar != thisChar) {
                    row.header = thisChar;
                    indexChar = thisChar;
                }
                shopTableData[i].push(row);

                // Create the table row for the all shop table data
                row = Ti.UI.createTableViewRow({
                    title : shops[i][j].shop_display,
                    shop : shops[i][j],
                    className : 'shopRow',
                    font : {
                        fontSize : fontSize
                    }
                });
                allShopData.push(row);
            }
        }

        // Prepare the category table records
        categoryTableData = [];
        for (var i = 0; i < categories.length; i++) {
            categoryTableData.push(Ti.UI.createTableViewRow({
                title : categories[i],
                className : 'categoryRow',
                category : shopTableData[i],
                font : {
                    fontSize : fontSize,
                    fontWeight: 'bold'
                }
            }));
        }

        // Sort the all shop table data
        var array = allShopData;
        for (var i = 0; i < array.length - 1; i++) {
            for (var j = 0; j < array.length - i - 1; j++) {
                if (array[j].shop.shop_display.toUpperCase() > array[j + 1].shop.shop_display.toUpperCase()) {
                    var temp = array[j];
                    array[j] = array[j + 1];
                    array[j + 1] = temp;
                }
            }
        }

        // Update the table data
        setTableData();
    };

    /*
     * Event handlers
     */
    var frontSearchChanged = function(e) {
        var isSearching = frontSearch.value.length > 0;
        frontIndex.data = isSearching ? allShopData : categoryTableData;
    };
    frontSearch.addEventListener('change', frontSearchChanged);

    /*
     * If a category on  front page is clicked, show the second shop list page
     * with the selected shop list.
     */
    frontIndex.addEventListener('click', function(e) {
        if (Ti.Platform.name == 'android') {
            frontSearch.value = "";
            Titanium.UI.Android.hideSoftKeyboard();
        }

        if (e.rowData.category) {
            indexTable.setData(e.rowData.category);
            indexTable.scrollToTop(0);
            directoryPane.setCurrentPage(1);
        } else {
            currentShop = e.rowData.shop;
            detailPhoto.image = 'http://lcx.itehk.com.hk/lcxapp/upload/shop/' + encodeURIComponent(currentShop.logo);
            shopName.text = currentShop.shop_display;
            tel.text = 'Tel:\t\t' + currentShop.tel;
            webSite.text = 'Web:\t' + currentShop.site;
            returnPage = 0;
            directoryPane.setCurrentPage(2);
        }
    });

    /*
     * If a shop on the second shop list page, show the third shop detail page
     * with the selected shop.
     */
    indexTable.addEventListener('click', function(e) {
        if (Ti.Platform.name == 'android') {
            indexSearch.value = "";
            Titanium.UI.Android.hideSoftKeyboard();
        }

        var index = e.index;
        currentShop = e.rowData.shop;
        detailPhoto.image = 'http://lcx.itehk.com.hk/lcxapp/upload/shop/' + encodeURIComponent(currentShop.logo);
        shopName.text = currentShop.shop_display;
        tel.text = (language == LANGUAGE_EN ? 'Tel' : '電話') + ':\t\t' + currentShop.tel;
        webSite.text = (language == LANGUAGE_EN ? 'Web' : '網址') + ':\t\t' + currentShop.site;
        returnPage = 1;
        directoryPane.setCurrentPage(2);
    });

    /*
     * If the Back image on the shop list page is clicked, switch back to the
     * first category list page.
     */
    indexBack.addEventListener('click', function(e) {
        directoryPane.setCurrentPage(0);
    });

    /*
     * If the Back image on the shop detail page is clicked, switch back to the
     * second shop list page.
     */
    imgFacebook.addEventListener('click', function(e) {
        var fb = require('facebook');
        fb.appid = '187761737927481';
        fb.permissions = ["user_checkins", "friends_checkins", "publish_checkins", "read_stream", "offline_access", "publish_stream"];
        fb.authorize();

        var data = {
            link : "http://www.facebook.com/lcxhk",
            name : language == LANGUAGE_EN ? "Recommend a shop in LCX" : '推薦你此LCX商戶',
            caption : shopName.text,
            picture : detailPhoto.image,
            description : webSite.text
        };
        fb.dialog("feed", data, function(e) {
        });
    });

    /*
     * If the Email image on the shop detail page is clicked, compose an email
     * and send it with the user selected email application. The email contains
     * an image of the shop, which is obtained from the web on the fly via AJAX.
     * Therefore, the email dialog is shown in the AJAX onload method.
     */
    imgEmail.addEventListener('click', function(e) {
        var emailDialog = Ti.UI.createEmailDialog();
        emailDialog.subject = "My favorite store in LCX";
        emailDialog.toRecipients = [];
        emailDialog.messageBody = shopName.text;

        var httpClient = Titanium.Network.createHTTPClient();
        httpClient.setTimeout(10000);
        httpClient.onload = function(e) {
            emailDialog.addAttachment(this.responseData);
            emailDialog.open();
        };
        httpClient.onerror = function(e) {
            emailDialog.open();
        };
        httpClient.open('GET', detailPhoto.image);
        httpClient.send();
    });

    /*
     * If the phone number of the shop is clicked, start the default application
     * to handle the phone number, which will start a dialer to make the phone
     * call.
     */
    tel.addEventListener('click', function(e) {
        var phone = currentShop.tel;

        if (phone != null && phone.length > 0 && phone != "none") {
            phone = "tel:" + phone;
            Titanium.Platform.openURL(phone);
        }
    });

    /*
     * If the URL of the shop is clicked, start the default application to handle
     * the link.
     */
    webSite.addEventListener('click', function(e) {
        var url = currentShop.site;

        if (url != null && url.length > 0 && url != "none") {
            if (url.substring(0, 7) != "http://") {
                url = "http://" + url;
            }
            Titanium.Platform.openURL(url);
        }
    });

    /*
     * If the Back image on the shop detail page is clicked, return to the shop
     * list page.
     */
    detailBack.addEventListener('click', function(e) {
        // The following program section is to prevent the app to crash
        // due to a known bug. For further details, please refer to the
        // following
        // URL, https://jira.appcelerator.org/browse/TIMOB-4348
        frontSearch = Ti.UI.createSearchBar({
            hintText : 'Search',
            showCancel : false
        });
        frontIndex.search = frontSearch;
        frontSearch.addEventListener('change', frontSearchChanged);

        directoryPane.setCurrentPage(returnPage);
    });

    /*
     * Public methods.
     */

    /*
     * Update the GUI according to the current language setting.
     */
    self.updateLanguage = function() {
        language = Ti.App.Properties.getString('language') == "english" ? LANGUAGE_EN : LANGUAGE_TC;
        indexBack.image = (language == LANGUAGE_EN ? '/images/btn_back.png' : '/images/btn_back_tc.png');
        imgFacebook.image = (language == LANGUAGE_EN ? '/images/btn_facebook.png' : '/images/btn_facebook_tc.png');
        detailBack.image = (language == LANGUAGE_EN ? '/images/btn_back.png' : '/images/btn_back_tc.png');
        frontSearch.hintText = (language == LANGUAGE_EN) ? 'Search' : '搜尋';
        indexSearch.hintText = (language == LANGUAGE_EN) ? 'Search' : '搜尋';
        if (currentShop != null) {
            tel.text = (language == LANGUAGE_EN ? 'Tel' : '電話') + ':\t\t' + currentShop.tel;
            webSite.text = (language == LANGUAGE_EN ? 'Web' : '網址') + ':\t\t' + currentShop.site;
        }
    };

    return self;
};

module.exports = DirectoryView;
