/**
 * Class definition of MainView. It defines the region under the title region at
 * the top.
 */
// @formatter:off
/**
 * Author: $Author: herbert $
 * URL: $HeadURL: svn+ssh://192.168.1.54/var/svn/LCX/Resources/ui/common/MainView.js $
 * Revision: $Id: MainView.js 125 2013-03-07 13:41:57Z herbert $
 */
// @formatter:on
function MainView() {
    /*
    * Variable declarations.
    */

    // Language constants
    var LANGUAGE_EN = 1;
    var LANGUAGE_TC = 2;

    // The current language.
    var language = Ti.App.Properties.getString('language') == "english" ? LANGUAGE_EN : LANGUAGE_TC;

    // The dimension of the device and the ratios for scaling the images.
    var platformWidth = Titanium.Platform.displayCaps.platformWidth < Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var platformHeight = Titanium.Platform.displayCaps.platformWidth > Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var widthRatio = platformWidth / 640.0;
    var heightRatio = platformHeight / 960.0;
    var smallRatio = widthRatio < heightRatio ? widthRatio : heightRatio;
    var bigRatio = widthRatio > heightRatio ? widthRatio : heightRatio;

    /*
     * Set up the layout of the view.
     */
    var self = Ti.UI.createView();

    var mainPane = Ti.UI.createView({
        top : 0,
        left : 0,
        right : 0,
        bottom : 98 * heightRatio,
        width : 'auto',
        scrollingEnabled : false
    });

    self.add(mainPane);

    /*
     * Create the four views that correspond to the four buttons at the bottom of
     * the screen, and a map view for showing the map of the store.
     */
    var WhatsOnView = require('ui/common/WhatsOnView');
    var whatsOn = new WhatsOnView();
    mainPane.add(whatsOn);

    // var SpecialOfferView = require('ui/common/SpecialOfferView');
    // var specialOffer = new SpecialOfferView();
    // mainPane.add(specialOffer);

    var MapWindow = require('ui/common/MapWindow');
    var mapWindow = new MapWindow();
    var DirectoryView = require('ui/common/DirectoryView');
    var directory = new DirectoryView(mapWindow);
    mainPane.add(directory);

    var AboutLCXView = require('ui/common/AboutLCXView');
    var aboutLCX = new AboutLCXView();
    mainPane.add(aboutLCX);

    /*
     * Create the four buttons at the bottom of the screen.
     */
    var buttonPane = Ti.UI.createView({
        backgroundColor : '#000',
        opacity : 1,
        bottom : 0,
        height : 98 * smallRatio,
        width : Ti.UI.FILL
    });
    self.add(buttonPane);

    var buttonTop = 0;
    var buttonLeft = (platformWidth / 3 - 160 * smallRatio) / 2;
    var btnWhatsOn = Ti.UI.createImageView({
        backgroundColor : '#000',
        image : (language == LANGUAGE_EN ? '/images/tabbar_icon01b.png' : '/images/tabbar_icon01b_tc.png'),
        top : buttonTop,
        left : buttonLeft,
        height : 98 * smallRatio,
        width : 160 * smallRatio
    });
    // buttonLeft += platformWidth / 4;
    // var btnSpecialOffer = Ti.UI.createImageView({
    // backgroundColor : '#000',
    // image : (language == LANGUAGE_EN ? '/images/tabbar_icon02a.png' :
    // '/images/tabbar_icon02a_tc.png'),
    // top : buttonTop,
    // left : buttonLeft,
    // height : 98 * smallRatio,
    // width : 160 * smallRatio
    // });
    buttonLeft += platformWidth / 3;
    var btnDirectory = Ti.UI.createImageView({
        backgroundColor : '#000',
        image : (language == LANGUAGE_EN ? '/images/tabbar_icon03a.png' : '/images/tabbar_icon03a_tc.png'),
        top : buttonTop,
        left : buttonLeft,
        height : 98 * smallRatio,
        width : 160 * smallRatio
    });
    buttonLeft += platformWidth / 3;
    var btnAboutLCX = Ti.UI.createImageView({
        backgroundColor : '#000',
        image : (language == LANGUAGE_EN ? '/images/tabbar_icon04a.png' : '/images/tabbar_icon04a_tc.png'),
        top : buttonTop,
        left : buttonLeft,
        height : 98 * smallRatio,
        width : 160 * smallRatio
    });

    buttonPane.add(btnWhatsOn);
    //    buttonPane.add(btnSpecialOffer);
    buttonPane.add(btnDirectory);
    buttonPane.add(btnAboutLCX);

    /*
     * Set default What's on view to be shown.
     */
    var views = [whatsOn, directory, aboutLCX];
    var currentIndex = 0;
    updateView(currentIndex);

    /*
     * Event handlers.
     */
    btnWhatsOn.addEventListener('click', function(e) {
        updateView(0);
    });
    // btnSpecialOffer.addEventListener('click', function(e) {
    // updateView(1);
    // });
    btnDirectory.addEventListener('click', function(e) {
        updateView(1);
    });
    btnAboutLCX.addEventListener('click', function(e) {
        updateView(2);
    });

    /*
     * Private function.
     */

    /*
     * Set the view specified by the index to be shown.
     */
    function updateView(index) {
        if (currentIndex == index)
            return;

        if (currentIndex == 0) {
            // If What's on is currently shown, it is to be hidden. Stop the
            // animation.
            views[0].stopAnimation();
        } else if (index == 0) {
            // If What's On is to be shown, start the animation.
            views[0].startAnimation();
        }

        for (var i = 0; i < views.length; i++) {
            views[i].setVisible(false);
        }

        // Dim the original button
        switch (currentIndex) {
            case 0:
                btnWhatsOn.image = (language == LANGUAGE_EN ? '/images/tabbar_icon01a.png' : '/images/tabbar_icon01a_tc.png');
                break;
            case 1:
                btnDirectory.image = (language == LANGUAGE_EN ? '/images/tabbar_icon03a.png' : '/images/tabbar_icon03a_tc.png');
                break;
            case 2:
                btnAboutLCX.image = (language == LANGUAGE_EN ? '/images/tabbar_icon04a.png' : '/images/tabbar_icon04a_tc.png');
                break;
        }

        // Highlight the new button
        switch (index) {
            case 0:
                btnWhatsOn.image = (language == LANGUAGE_EN ? '/images/tabbar_icon01b.png' : '/images/tabbar_icon01b_tc.png');
                break;
            case 1:
                btnDirectory.image = (language == LANGUAGE_EN ? '/images/tabbar_icon03b.png' : '/images/tabbar_icon03b_tc.png');
                break;
            case 2:
                btnAboutLCX.image = (language == LANGUAGE_EN ? '/images/tabbar_icon04b.png' : '/images/tabbar_icon04b_tc.png');
                break;
        }

        currentIndex = index;
        views[currentIndex].setVisible(true);
    }

    /*
     * Public functions.
     */

    /*
     * Update the language of the app. It gets latest langauge setting from the
     * system (which should be just set somewhere else), and update itself and
     * other associated GUI objects.
     */
    self.updateLanguage = function() {
        // Get the current language setting
        language = Ti.App.Properties.getString('language') == "english" ? LANGUAGE_EN : LANGUAGE_TC;

        // Update the four buttons at the bottom
        btnWhatsOn.image = language == LANGUAGE_EN ? 
            (currentIndex == 0 ? '/images/tabbar_icon01b.png' : '/images/tabbar_icon01a.png') : 
            (currentIndex == 0 ? '/images/tabbar_icon01b_tc.png' : '/images/tabbar_icon01a_tc.png');
        // btnSpecialOffer.image = (language == LANGUAGE_EN ?
        // '/images/tabbar_icon02a.png' : '/images/tabbar_icon02a_tc.png');
        btnDirectory.image = language == LANGUAGE_EN ? 
            (currentIndex == 1 ? '/images/tabbar_icon03b.png' : '/images/tabbar_icon03a.png') : 
            (currentIndex == 1 ? '/images/tabbar_icon03b_tc.png' : '/images/tabbar_icon03a_tc.png');
        btnAboutLCX.image = language == LANGUAGE_EN ? 
            (currentIndex == 2 ? '/images/tabbar_icon04b.png' : '/images/tabbar_icon04a.png') : 
            (currentIndex == 2 ? '/images/tabbar_icon04b_tc.png' : '/images/tabbar_icon04a_tc.png');

        // Update other associated GUI objects.
        whatsOn.updateLanguage();
        // specialOffer.updateLanguage();
        directory.updateLanguage();
        aboutLCX.updateLanguage();
        mapWindow.updateLanguage();
    };

    self.loadContent = function(callback) {
        /*
         * Get data from the web server via AJAX. Upon the arrival of data,
         * update the corresponding GUI objects with the data.
         */
        var urlCompleted = 0;
        var url = "http://lcx.itehk.com.hk/lcxapp/LCXJsonServ_running.php";
        var client = Ti.Network.createHTTPClient({
            onload : function(e) {
                var objs = JSON.parse(this.responseText);
                whatsOn.updateRunningText(objs);
                urlCompleted--;
                if (urlCompleted == 0 && callback != null) {
                    callback();
                }
            },
            onerror : function(e) {
                Ti.API.debug(e.error);
            },
            timeout : 10000 // in milliseconds
        });
        client.open("GET", url);
        client.send();
        urlCompleted++;

        url = "http://lcx.itehk.com.hk/lcxapp/LCXJsonServ_promotion.php";
        client = Ti.Network.createHTTPClient({
            onload : function(e) {
                var objs = JSON.parse(this.responseText);
                whatsOn.updatePromotions(objs);
                urlCompleted--;
                if (urlCompleted == 0 && callback != null) {
                    callback();
                }
            },
            onerror : function(e) {
                Ti.API.debug(e.error);
            },
            timeout : 10000 // in milliseconds
        });
        client.open("GET", url);
        client.send();
        urlCompleted++;

        url = "http://lcx.itehk.com.hk/lcxapp/LCXJsonServ_shop.php";
        client = Ti.Network.createHTTPClient({
            onload : function(e) {
                var objs = JSON.parse(this.responseText);
                // specialOffer.updateSpecialOffers(objs);
                directory.updateDirectory(objs);
                urlCompleted--;
                if (urlCompleted == 0 && callback != null) {
                    callback();
                }
            },
            onerror : function(e) {
                Ti.API.debug(e.error);
            },
            timeout : 10000 // in milliseconds
        });
        client.open("GET", url);
        client.send();
        urlCompleted++;

        url = "http://lcx.itehk.com.hk/lcxapp/LCXJsonServ_location.php?action=location&location=Harbour%20City";
        client = Ti.Network.createHTTPClient({
            onload : function(e) {
                var objs = JSON.parse(this.responseText);
                mapWindow.updateLocation(objs);
                urlCompleted--;
                if (urlCompleted == 0 && callback != null) {
                    callback();
                }
            },
            onerror : function(e) {
                Ti.API.debug(e.error);
            },
            timeout : 10000 // in milliseconds
        });
        client.open("GET", url);
        client.send();
        urlCompleted++;
    };

    return self;
};

module.exports = MainView;
