/**
 * Class definition of SpecialOfferView. It defines the region for showing
 * special offers.
 */
// @formatter:off
/**
 * Author: $Author: herbert $
 * URL: $HeadURL: svn+ssh://192.168.1.54/var/svn/LCX/Resources/ui/common/SpecialOfferView.js $
 * Revision: $Id: SpecialOfferView.js 125 2013-03-07 13:41:57Z herbert $
 */
// @formatter:on
function SpecialOfferView() {
    /*
     * Variable declaration.
     */
    var LANGUAGE_EN = 1;
    var LANGUAGE_TC = 2;

    var language = Ti.App.Properties.getString('language') == "english" ? LANGUAGE_EN : LANGUAGE_TC;

    var platformWidth = Titanium.Platform.displayCaps.platformWidth < Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var platformHeight = Titanium.Platform.displayCaps.platformWidth > Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var widthRatio = platformWidth / 640.0;
    var heightRatio = platformHeight / 960.0;
    var smallRatio = widthRatio < heightRatio ? widthRatio : heightRatio;
    var bigRatio = widthRatio > heightRatio ? widthRatio : heightRatio;
    var fontSize = platformHeight / 40;

    /*
     * Construct this object.
     */
    var self = Titanium.UI.createView({
        left : 15 * smallRatio,
        top : 15 * smallRatio,
        right : 15 * smallRatio,
        bottom : 0 * smallRatio,
        visible : false,
        backgroundImage : '/images/back_popup.png'
    });

    /*
     * Prepare the layout.
     */
    var specialOfferPane = Ti.UI.createScrollableView({
        scrollingEnabled : false
    });
    self.add(specialOfferPane);

    var indexPage = Ti.UI.createTableView();
    specialOfferPane.addView(indexPage);

    var specialOfferDetailView = Ti.UI.createView({
        width : 'auto',
        height : 'auto'
    });
    specialOfferPane.addView(specialOfferDetailView);

    var specialOfferDetailPage = Ti.UI.createView({
        left : 15 * smallRatio,
        top : 15 * smallRatio,
        right : 15 * smallRatio,
        bottom : 15 * smallRatio,
        backgroundImage : '/images/back_popup.png'
    });
    specialOfferDetailView.add(specialOfferDetailPage);

    specialOfferDetailPane = Ti.UI.createScrollView({
        width : Ti.UI.FILL,
        height : Ti.UI.FILL,
        layout : 'vertical'
    });
    specialOfferDetailPage.add(specialOfferDetailPane);

    var image = Ti.UI.createImageView({
        top : 20 * smallRatio,
        left : 'auto',
        right : 'auto',
        width : platformWidth - 30 * smallRatio
    });
    var shopName = Ti.UI.createLabel({
        top : 20 * smallRatio,
        width : platformWidth - 80 * widthRatio,
        height : Ti.UI.SIZE,
        color : 'white',
        font : {
            fontSize : fontSize
        }
    });
    var description = Ti.UI.createLabel({
        top : 20 * smallRatio,
        width : platformWidth - 80 * widthRatio,
        height : Ti.UI.SIZE,
        color : 'white',
        font : {
            fontSize : fontSize
        }
    });
    specialOfferDetailPane.add(image);
    specialOfferDetailPane.add(shopName);
    specialOfferDetailPane.add(description);

    var buttonPanel = Ti.UI.createView({
        width : 'auto',
        left : 10 * smallRatio,
        right : 10 * smallRatio,
        height : 50 * smallRatio,
        bottom : 0
    });
    specialOfferDetailPage.add(buttonPanel);

    var imgFacebook = Ti.UI.createImageView({
        top : 5 * smallRatio,
        left : 10 * widthRatio,
        width : 116 * smallRatio,
        height : 40 * smallRatio,
        image : (language == LANGUAGE_EN ? '/images/btn_facebook.png' : '/images/btn_facebook_tc.png')
    });
    var imgEmail = Ti.UI.createImageView({
        top : 7 * smallRatio,
        left : 150 * widthRatio,
        width : 36 * smallRatio,
        height : 35 * smallRatio,
        image : '/images/btn_email.png'
    });
    var imgBack = Ti.UI.createImageView({
        top : 2 * smallRatio,
        right : 10 * widthRatio,
        width : 120 * smallRatio,
        height : 45 * smallRatio,
        image : (language == LANGUAGE_EN ? '/images/btn_back.png' : '/images/btn_back_tc.png')
    });

    buttonPanel.add(imgFacebook);
    buttonPanel.add(imgEmail);
    buttonPanel.add(imgBack);

    var engOffers = [];
    var chnOffers = [];

    /*
     * Event handlers.
     */
    indexPage.addEventListener('click', function(e) {
        var row = e.row;
        specialOfferPane.setCurrentPage(1);
        image.image = row.detailImage;
        shopName.text = row.shopName;
        description.text = row.detailDescription;
    });

    imgFacebook.addEventListener('click', function(e) {
        var fb = require('facebook');
        fb.appid = '187761737927481';
        fb.permissions = ["user_checkins", "friends_checkins", "publish_checkins", "read_stream", "offline_access", "publish_stream"];
        fb.authorize();

        var data = {
            link : "http://www.facebook.com/lcxhk",
            name : language == LANGUAGE_EN ? "Recommend a LCX promotion to you" : '推薦你此 LCX 最新推廣',
            caption : shopName.text,
            picture : image.image,
            description : description.text
        };
        fb.dialog("feed", data, function(e) {
        });
    });

    imgEmail.addEventListener('click', function(e) {
        var emailDialog = Ti.UI.createEmailDialog();
        emailDialog.subject = language == LANGUAGE_EN ? "Recommend a LCX promotion to you" : '推薦你此 LCX 今期推廣';
        emailDialog.toRecipients = [];
        emailDialog.messageBody = shopName.text + "\n" + description.text;

        var httpClient = Titanium.Network.createHTTPClient();
        httpClient.setTimeout(10000);
        httpClient.onload = function(e) {
            emailDialog.addAttachment(this.responseData);
            emailDialog.open();
        };
        httpClient.onerror = function(e) {
            emailDialog.open();
        };
        httpClient.open('GET', image.image);
        httpClient.send();
    });

    imgBack.addEventListener('click', function(e) {
        specialOfferPane.setCurrentPage(0);
    });

    /*
     * Private utility functions.
     */

    /*
     * Update the table by specifying the language to be used.
     */
    function updateTable(lang) {
        language = lang;
        indexPage.setData((language == LANGUAGE_EN) ? engOffers : chnOffers);
    }

    /*
     * Public functions.
     */

    /*
     * Update the special offer data by the specified object. The object supplied
     * to this method refers to an array of shop objects and only some of them
     * defines special offers. Among the offers, only those still valid are added
     * to the data to be shown.
     */
    self.updateSpecialOffers = function(objs) {
        // Prepare today's date'
        var currentTime = new Date();
        var month = currentTime.getMonth() + 1;
        if (month < 10)
            month = '0' + month;
        var day = currentTime.getDate();
        if (day < 10)
            day = '0' + day;
        var year = currentTime.getFullYear();
        var today = year + "-" + month + "-" + day;

        // For each shop object, determine whether it defines valid offer
        for (var i = 0; i < objs.shop.length; i++) {
            if (objs.shop[i].offer_start_date == "none" || objs.shop[i].offer_end_date == "none") {
                continue;
            }

            // If the shop object is still valid
            if (objs.shop[i].offer_start_date <= today && today <= objs.shop[i].offer_end_date) {
                // Prepare the English row
                var row = Ti.UI.createTableViewRow();
                row.shopName = objs.shop[i].shop_display;
                row.detailImage = 'http://lcx.itehk.com.hk/lcxapp/upload/shop/' + encodeURIComponent(objs.shop[i].offer_logo_large);
                row.detailDescription = objs.shop[i].offer_english;
                row.add(Ti.UI.createImageView({
                    image : 'http://lcx.itehk.com.hk/lcxapp/upload/shop/' + encodeURIComponent(objs.shop[i].offer_logo_small),
                    top : 40 * smallRatio,
                    left : 40 * smallRatio,
                    width : 128 * smallRatio,
                    height : 'auto',
                    clickName : 'image'
                }));
                row.add(Ti.UI.createLabel({
                    top : 40 * smallRatio,
                    left : 180 * smallRatio,
                    right : 40 * smallRatio,
                    bottom : 0,
                    width : 'auto',
                    height : 200 * smallRatio,
                    ellipsize : true,
                    clickName : 'text',
                    verticalAlign : Titanium.UI.TEXT_VERTICAL_ALIGNMENT_TOP,
                    text : objs.shop[i].offer_english,
                    font : {
                        fontSize : fontSize
                    }
                }));
                engOffers.push(row);

                // Prepare the Chinese row
                row = Ti.UI.createTableViewRow();
                row.shopName = objs.shop[i].shop_display;
                row.detailImage = 'http://lcx.itehk.com.hk/lcxapp/upload/shop/' + encodeURIComponent(objs.shop[i].offer_logo_large);
                row.detailDescription = objs.shop[i].offer_chinese;
                row.add(Ti.UI.createImageView({
                    image : 'http://lcx.itehk.com.hk/lcxapp/upload/shop/' + encodeURIComponent(objs.shop[i].offer_logo_small),
                    top : 40 * smallRatio,
                    left : 40 * smallRatio,
                    width : 128 * smallRatio,
                    height : 'auto',
                    clickName : 'image'
                }));
                row.add(Ti.UI.createLabel({
                    top : 40 * smallRatio,
                    left : 180 * smallRatio,
                    right : 40 * smallRatio,
                    bottom : 0,
                    width : 'auto',
                    height : 200 * smallRatio,
                    ellipsize : true,
                    clickName : 'text',
                    verticalAlign : Titanium.UI.TEXT_VERTICAL_ALIGNMENT_TOP,
                    text : objs.shop[i].offer_chinese,
                    font : {
                        fontSize : fontSize
                    }
                }));
                chnOffers.push(row);
            }
        }

        // After the data are updated, update the table with the method.
        updateTable(language);
    };

    /*
     * Update the user interface with the current language setting.
     */
    self.updateLanguage = function() {
        // Get the current language setting
        language = Ti.App.Properties.getString('language') == "english" ? LANGUAGE_EN : LANGUAGE_TC;

        // Update the GUI component title / label
        imgFacebook.image = (language == LANGUAGE_EN ? '/images/btn_facebook.png' : '/images/btn_facebook_tc.png');
        imgBack.image = (language == LANGUAGE_EN ? '/images/btn_back.png' : '/images/btn_back_tc.png');
        indexPage.setData((language == LANGUAGE_EN) ? engOffers : chnOffers);

        // Switch the first page of this view, so that the offer text will not be
        // shown in a wrong language.
        specialOfferPane.setCurrentPage(0);

        imgFacebook.left = 10;
    };

    return self;
};

module.exports = SpecialOfferView;
