/**
 * The class definition of TitleView. It accepts a parameter of a MainView object
 * that occupies the lower part of the app.
 */
// @formatter:off
/**
 * Author: $Author: herbert $
 * URL: $HeadURL: svn+ssh://192.168.1.54/var/svn/LCX/Resources/ui/common/TitleView.js $
 * Revision: $Id: TitleView.js 125 2013-03-07 13:41:57Z herbert $
 */
// @formatter:on
function TitleView(mv) {
    // Store the reference to the MainView object.
    var mainView = mv;

    /*
     * Get the screen width. As the app just support portrait direction, if the
     * app is started when the device is positioned in landscape direction, the
     * width is then the size of the longer side of the device by mistake.
     * Therefore, compare the height and the width of the device and treat the
     * shorter one as the width.
     */
    var platformWidth = Titanium.Platform.displayCaps.platformWidth < Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var platformHeight = Titanium.Platform.displayCaps.platformWidth > Titanium.Platform.displayCaps.platformHeight ? Titanium.Platform.displayCaps.platformWidth : Titanium.Platform.displayCaps.platformHeight;
    var widthRatio = platformWidth / 640.0;
    var heightRatio = platformHeight / 960.0;
    var smallRatio = widthRatio < heightRatio ? widthRatio : heightRatio;
    var bigRatio = widthRatio > heightRatio ? widthRatio : heightRatio;

    /*
     * Set up the view layout.
     */
    var self = Titanium.UI.createView({
        top : 0,
        left : 0,
        right : 0,
        height : 80 * smallRatio,
        width : Ti.UI.FILL,
        opacity : 1
    });

    var isAndroid = Ti.Platform.osname == 'android';

    var logo = Ti.UI.createImageView({
        top : 0,
        left : (platformWidth - 80 * smallRatio) / 2,
        height : 80 * smallRatio,
        width : 80 * smallRatio,
        image : '/images/logo_top_lcx.png',
        opacity : 1
    });
    self.add(logo);

    var setting = Ti.UI.createImageView({
        top : 0,
        right : 0,
        height : 55 * smallRatio,
        width : 55 * smallRatio,
        image : '/images/btn_setting.png',
        opacity : 1
    });
    self.add(setting);

    /*
     * Add event handlers.
     */

    /*
     * Show the option dialog if the setting button is clicked. It shows an
     * option dialog with current setting. When the dialog is clicked (closed),
     * get the setting, store it and update the entire app.
     */
    setting.addEventListener('click', function(e) {
        var optionsDialogOpts = {
            options : ['English', '中文'],
            title : 'Language / 語言'
        };

        if (isAndroid) {
            optionsDialogOpts.selectedIndex = Ti.App.Properties.getString('language') == "english" ? 0 : 1;
        }

        var dialog = Titanium.UI.createOptionDialog(optionsDialogOpts);

        dialog.addEventListener('click', function(e) {
            Ti.App.Properties.setString("language", e.index == 0 ? "english" : "chinese");
            mv.updateLanguage();
        });
        dialog.show();
    });

    return self;
};

module.exports = TitleView;
